@@ -11,15 +11,12 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -29,6 +26,7 @@ else:
 __all__ = (
     "ColumnMetadataTypeDef",
     "FieldTypeDef",
+    "ResponseMetadata",
     "StatementDataTypeDef",
     "TableMemberTypeDef",
     "CancelStatementResponseTypeDef",
@@ -76,6 +74,17 @@ FieldTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredStatementDataTypeDef = TypedDict("_RequiredStatementDataTypeDef", {"Id": str})
 _OptionalStatementDataTypeDef = TypedDict(
     "_OptionalStatementDataTypeDef",
@@ -149,6 +158,7 @@ ExecuteStatementOutputTypeDef = TypedDict(
         "DbUser": str,
         "Id": str,
         "SecretArn": str,
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
